@@ -363,7 +363,8 @@ class DistUpgradeController(object):
         logging.debug("_pythonSymlinkCheck run")
         if os.path.exists('/usr/share/python/debian_defaults'):
             config = SafeConfigParser()
-            config.readfp(open('/usr/share/python/debian_defaults'))
+            with open('/usr/share/python/debian_defaults') as f:
+                config.readfp(f)
             try:
                 expected_default = config.get('DEFAULT', 'default-version')
             except NoOptionError:
@@ -459,16 +460,6 @@ class DistUpgradeController(object):
             logging.error("checkViewDepends() failed")
             return False
 
-        if os.path.exists("/usr/bin/debsig-verify"):
-            logging.error("debsig-verify is installed")
-            self._view.error(_("Package 'debsig-verify' is installed"),
-                             _("The upgrade can not continue with that "
-                               "package installed.\n"
-                               "Please remove it with synaptic "
-                               "or 'apt-get remove debsig-verify' first "
-                               "and run the upgrade again."))
-            self.abort()
-
         from .DistUpgradeMain import SYSTEM_DIRS
         for systemdir in SYSTEM_DIRS:
             if os.path.exists(systemdir) and not os.access(systemdir, os.W_OK):
@@ -562,7 +553,8 @@ class DistUpgradeController(object):
                         s += "deb http://archive.ubuntu.com/ubuntu %s main restricted" % self.toDist
                         s += "deb http://archive.ubuntu.com/ubuntu %s-updates main restricted" % self.toDist
                         s += "deb http://security.ubuntu.com/ubuntu %s-security main restricted" % self.toDist
-                        open("/etc/apt/sources.list","w").write(s)
+                        with open("/etc/apt/sources.list","w") as f:
+                            f.write(s)
                     break
 
         # this must map, i.e. second in "from" must be the second in "to"
@@ -575,6 +567,20 @@ class DistUpgradeController(object):
                                    for x in pockets]
         self.sources_disabled = False
 
+        # Special quirk to remove extras.ubuntu.com
+        new_list = []
+        for entry in self.sources.list[:]:
+            if "/extras.ubuntu.com" in entry.uri:
+                continue
+            if entry.line.startswith(
+                    "## This software is not part of Ubuntu, but is offered by third-party"):
+                continue
+            if entry.line.startswith(
+                    "## developers who want to ship their latest software."):
+                continue
+            new_list.append(entry)
+        self.sources.list = new_list
+
         # look over the stuff we have
         foundToDist = False
         # collect information on what components (main,universe) are enabled for what distro (sub)version
@@ -667,8 +673,7 @@ class DistUpgradeController(object):
                     "/security.ubuntu.com" in entry.uri or
                     "%s-security" % self.fromDist in entry.dist or
                     "%s-backports" % self.fromDist in entry.dist or
-                    "/archive.canonical.com" in entry.uri or
-                    "/extras.ubuntu.com" in entry.uri):
+                    "/archive.canonical.com" in entry.uri):
                     validTo = False
                 if entry.dist in toDists:
                     # so the self.sources.list is already set to the new
@@ -1137,7 +1142,8 @@ class DistUpgradeController(object):
                 # the previous release, no packages have been installed
                 # yet (LP: #328655, #356781)
                 if os.path.exists("/var/run/ubuntu-release-upgrader-apt-exception"):
-                    e = open("/var/run/ubuntu-release-upgrader-apt-exception").read()
+                    with open("/var/run/ubuntu-release-upgrader-apt-exception") as f:
+                        e = f.read()
                     logging.error("found exception: '%s'" % e)
                     # if its a ordering bug we can cleanly revert but we need to write
                     # a marker for the parent process to know its this kind of error
@@ -1483,14 +1489,13 @@ class DistUpgradeController(object):
         # go over the sources.list and try to find a valid mirror
         # that we can use to add the backports dir
         logging.debug("writing prerequists sources.list at: '%s' " % out)
-        outfile = open(out, "w")
         mirrorlines = self._getPreReqMirrorLines(dumb)
-        for line in open(template):
-            template = Template(line)
-            outline = template.safe_substitute(mirror=mirrorlines)
-            outfile.write(outline)
-            logging.debug("adding '%s' prerequists" % outline)
-        outfile.close()
+        with open(out, "w") as outfile, open(template) as infile:
+            for line in infile:
+                template = Template(line)
+                outline = template.safe_substitute(mirror=mirrorlines)
+                outfile.write(outline)
+                logging.debug("adding '%s' prerequists" % outline)
         return True
 
     def getRequiredBackports(self):
@@ -1748,6 +1753,10 @@ class DistUpgradeController(object):
                 #        (i.e. the error here could be something else than
                 #        missing sources entries but network errors etc)
                 logging.error("No '%s' available/downloadable after sources.list rewrite+update" % pkg)
+                if pkg not in self.cache:
+                    logging.error("'%s' was not in the cache" % pkg)
+                if not self.cache.anyVersionDownloadable(self.cache[pkg]):
+                    logging.error("'%s' was not downloadable" % pkg)
                 self._view.error(_("Invalid package information"),
                                  _("After updating your package "
                                    "information, the essential package '%s' "
